local _G = _G
local tonumber = _G.tonumber

local AceLibrary = _G.AceLibrary

local MAJOR_VERSION = "Threat-1.0"
local MINOR_VERSION = tonumber(("$Revision: 37072 $"):match("%d+"))

if _G.ThreatLib_OUT_OF_DATE or not AceLibrary:IsNewVersion(MAJOR_VERSION, MINOR_VERSION) then
	_G.ThreatLib_OUT_OF_DATE = true
	return
end

if MINOR_VERSION > _G.ThreatLib_MINOR_VERSION then
	_G.ThreatLib_MINOR_VERSION = MINOR_VERSION
end

local ThreatLib = _G.ThreatLib

local _, c = _G.UnitClass("player")
if c ~= "HUNTER" then return end 

local BS = AceLibrary("Babble-Spell-2.2")
local Aura = AceLibrary("SpecialEvents-Aura-2.0")
ThreatLib:GetModule("ClassCore"):SetModuleDefaultState(c, false)
local Hunter = ThreatLib:GetModule("ClassCore"):NewModule(c)

local distractThreatAmounts		= {110, 160, 250, 350, 465, 600, 900}
local disengageThreatAmounts	= {-140, -280, -405, -545}
	
function Hunter:ClassInit()
	self.className = "HUNTER"
	
	-- CastHandlers
	self.CastHandlers[BS["Distracting Shot"]] 	= self.DistractingShot
	self.CastHandlers[BS["Disengage"]]			= self.Disengage
	self.CastHandlers[BS["Feign Death"]]		= self.FeignDeath

	-- ClassBuffs
	self.ClassBuffs[BS["Misdirection"]]			= self.MisdirectionBuff
end

function Hunter:DistractingShot(rank)
	local ranknum = tonumber(rank:match("%d+"))
	self:AddTargetThreat(distractThreatAmounts[ranknum] * self:threatMods())
end

function Hunter:Disengage(rank)
	local ranknum = tonumber(rank:match("%d+"))
	self:AddTargetThreat(disengageThreatAmounts[ranknum] * self:threatMods())
end

function Hunter:FeignDeath()
	self:ReduceAllThreat(0)
end

function Hunter:MisdirectionBuff(action, rank, apps)
	-- Previous implementation was a bit too clever :P
	if action == self.LOSING_BUFF then
		self:RedirectThreatTo(nil)
	elseif action == self.GAINING_BUFF then
		self:RedirectThreatTo(self.currentTarget)
	end
end

_G.tinsert(ThreatLib.UpvalueFixers, function(lib) ThreatLib = lib end)
