local _G = _G
local ipairs = _G.ipairs
local select = _G.select
local GetTalentInfo = _G.GetTalentInfo
local AceLibrary = _G.AceLibrary

local MAJOR_VERSION = "Threat-1.0"
local MINOR_VERSION = _G.tonumber(("$Revision: 37072 $"):match("%d+"))

if _G.ThreatLib_OUT_OF_DATE or not AceLibrary:IsNewVersion(MAJOR_VERSION, MINOR_VERSION) then
	_G.ThreatLib_OUT_OF_DATE = true
	return
end

if MINOR_VERSION > _G.ThreatLib_MINOR_VERSION then
	_G.ThreatLib_MINOR_VERSION = MINOR_VERSION
end

local _, c = _G.UnitClass("player")
if c ~= "PALADIN" then return end 

local ThreatLib = _G.ThreatLib

local BS = AceLibrary("Babble-Spell-2.2")
ThreatLib:GetModule("ClassCore"):SetModuleDefaultState(c, false)
local Paladin = ThreatLib:GetModule("ClassCore"):NewModule(c)
local Aura = AceLibrary("SpecialEvents-Aura-2.0")

local irfRanks = {0, 0.16, 0.33, 0.5}

local HolyHealsEN = {
	"Holy Light", "Holy Shock", "Lay on Hands", "Seal of Light", "Flash of Light"
}

-- These abilities seem to be modified by global modifiers, like Salvation
-- They're obviously incomplete, but data collected so far shows that they're not too significant
-- Unused for now
local buffThreatValues = {
		[BS["Blessing of Might"]] = {5, 10, 25, 35, 45, 55, 65, 75},
		[BS["Blessing of Freedom"]] = {20},
		[BS["Blessing of Salvation"]] = {20},
		[BS["Blessing of Kings"]] = {20},
		[BS["Hammer of Justice"]] = {15, 50, 80},
		[BS["Seal of Justice"]] = {25, 50},
		[BS["Seal of Wisdom"]] = {25, 50},
		[BS["Seal of Righteousness"]] = {nil, nil, nil, nil, nil, 45}
}

function Paladin:ClassInit()
	self.className = "PALADIN"
	self.passiveThreatModifiers = 1
	
	self.schoolThreatMods["Holy"] = self.RighteousFury

	local healMod = function(self, amt, isDamage)
		local dMod = 1
		if isDamage then
			dMod = 2
		end
		return self:RighteousFury(amt) * 0.5 * dMod
	end

	for _,v in ipairs(HolyHealsEN) do
		self.abilityThreatMods[BS[v]] = healMod
	end
	
	self.abilityThreatMods[BS["Holy Shield"]] = function(self, amt, isDamage)
		return amt * 1.35
	end
	
	HolyHealsEN = nil
end

function Paladin:ScanTalents()
	-- Scan talents
	self.righteousFuryMod = 1.6 + (irfRanks[select(5, GetTalentInfo(2, 7))+1] * 0.6)
end

function Paladin:RighteousFury(amt)
	for buffName, index, applications, texture, rank in Aura:BuffIter("player") do
		if buffName == BS["Righteous Fury"] then
			return amt * self.righteousFuryMod
		end
	end
	return amt
end

_G.tinsert(ThreatLib.UpvalueFixers, function(lib) ThreatLib = lib end)
